; Removes trailing zeros and/or decimal from string,
; Assumes trailing spaces have already been removed.
function slice2d_remove_zeros, sval

    compile_opt idl2, hidden
  
  if ~stregex(sval, '\.', /bool) then return, sval

  f = stregex(sval, '0*$',length=len)

  if stregex(sval, '\.0*$', /bool) then len++

  return, strmid(sval, 0, (strlen(sval)-len) )

end



; Procedure to generate titles for plot and axes
;
pro plot_part_slice2d_getinfo, slice, title=title, subtitle=subtitle, $
                               xtitle=xtitle, ytitle=ytitle, ztitle=ztitle

    compile_opt idl2, hidden


  ; Plot title
  if arg_present(title) and ~keyword_set(title) then begin
    title = 'th'+strlowcase(slice.probe)+' ' + $
            strjoin(slice.dist,'/') + $
            ' ('+strupcase(slice.rot)+') ' + $
;            string(10b) + $ 
            time_string(slice.trange[0]) + $
            ' -> '+strmid(time_string(slice.trange[1]),11,8)
  endif

  ; X,Y axes labels
  xc = 1 & yc = 1
  if (arg_present(xtitle) or arg_present(ytitle)) and $
     (~keyword_set(xtitle) or ~keyword_set(ytitle)) then begin
    xt = 'Vx'   ;Defaults
    yt = 'Vy'
    xyunits = 'km/s'
    case strlowcase(slice.rot) of 
      'bv': begin
        xt = 'V!DB!N'
        yt = 'V!DV!N'
        xc = 0 & yc = 0
      end
      'be': begin
        xt = 'V!DB!N'
        yt = 'V!DB x V!N'
        xc = 0 & yc = 0
      end
      'xy': begin
        xt = 'Vx'
        yt = 'Vy'
      end
      'xz': begin
        xt = 'Vx'
        yt = 'Vz'
      end
      'yz': begin
        xt = 'Vy'
        yt = 'Vz'
      end
      'xvel': begin
        xt = 'Vx'
        yt = 'V!DV!N'
        yc = 0
      end
      'perp': begin
        xt = 'V!DV perp B!N'
        yt = 'V!DB x V!N'
        xc = 0 & yc = 0
      end
      'perp_xy': begin
        xt = 'Vx!Dperp!N'
        yt = 'Vy!Dperp!N'
      end
      'perp_xz': begin
        xt = 'Vx!Dperp!N'
        yt = 'Vz!Dperp!N'
      end
      'perp_yz': begin
        xt = 'Vy!Dperp!N' 
        yt = 'Vz!Dperp!N'
      end
      'rgeo': xt = 'V!Dr (GEI)!N'
      'mrgeo': xt = 'V!D-r (GEI)!N'
      'phigeo': yt = 'V!DEast (GEI)!N'
      'mphigeo': yt = 'V!DWest (GEI)!N'
      'phism': yt = 'V!DEast (SM)!N'
      'mphism': yt = 'V!DWest (SM)!N'
      'xgse': xt = 'Vx!DGSE!N'
      'ygsm': yt = 'Vy!DGSM!N'
      'zdsl': yt = 'Vz!DDSL!N'
      else: begin
        xt = 'Vx!D?!N'  ;shouldn't be used
        yt = 'Vy!D?!N'
      end
    endcase
    
    ; add units 
    xt += ' ('+xyunits+')'
    yt += ' ('+xyunits+')'
    
    ; specify original physical coords
    coords = slice.coord
    fac_coords = ['rgeo','mrgeo','phigeo','mphigeo', $
                  'phism','mphism','xgse','ygsm','zdsl']
    facidx = where(strlowcase(slice.rot) eq fac_coords, nfac)
    if nfac gt 0 then coords = slice.rot
    if xc then xt += ' ('+strupcase(coords)+')'
    if yc then yt += ' ('+strupcase(coords)+')'

    ; check for rotation out of x-y plane and label
    if n_elements(slice.orient_m) gt 1 then begin
      xvec = [1,0,0]##slice.orient_m
      yvec = [0,1,0]##slice.orient_m
      if in_set(xvec eq [1,0,0],0) then begin
        xv = strtrim(xvec,2)
        xt += ' - Using ('+ $
                  slice2d_remove_zeros(xv[0])+', '+ $
                  slice2d_remove_zeros(xv[1])+', '+ $
                  slice2d_remove_zeros(xv[2])+') as x-axis'
      endif
      if in_set(yvec eq [0,1,0],0) then begin
        yv = strtrim(yvec,2)
        yt += ' - Using ('+ $
                  slice2d_remove_zeros(yv[0])+', '+ $
                  slice2d_remove_zeros(yv[1])+', '+ $
                  slice2d_remove_zeros(yv[2])+') as y-axis'
      endif
    endif
    
    ;ensure custom titles are not overwritten
    if ~keyword_set(xtitle) then xtitle = xt
    if ~keyword_set(ytitle) then ytitle = yt
    
  endif
  
  
  ; Z axis label
  if arg_present(ztitle) and ~keyword_set(ztitle) then begin 
    ; convert time window to string and trim zeros
    twin = slice2d_remove_zeros(strtrim(slice.twin,2))
    ztitle = units_string(strlowcase(slice.units))
  endif


  ; Label slice type
  if arg_present(type) then begin
    type = (['Geo','2D nn','2D i','3D i'])[slice.type]
  endif


end


; **This fuction moved to thm_part_dist_array 2012-12-??**
; 
;; Find the sun direcion vector
;function plot_part_slice2d_getsun, slice, fail=fail
;
;    compile_opt idl2, hidden
;
;  
;  coord = strlowcase(slice.coord)
;  probe = strlowcase(slice.probe)
;  trange = slice.trange
;  
;  ; Caculation needed for dsl
;  if stregex(coord, '^dsl$', /bool, /fold_case) then begin 
;    dprint, dlevel=4, 'Finding sun direction in DSL...'
;    ctn = '2dslice_temp_sundir'
;    
;    ;Get support data
;    thm_load_state, probe=probe, trange=trange + 120*[-1,1], suffix='_'+ctn, $
;                    /get_support_data
;
;    ;Transform GSE basis vectors
;    store_data, ctn, data = {x:replicate(mean(trange),3), $
;                             y: [ [1.,0,0], [0,1,0], [0,0,1] ] }
;    thm_cotrans, ctn, probe=probe, in_coord='gse', out_coord=coord, $
;                 support_suffix='_'+ctn, out_suff='_'+coord
;
;    ;Transformed x-axis is DSL sun direction
;    get_data, ctn+'_'+coord, data=ctd
;    if size(ctd,/type) ne 8 then begin
;      fail = 'Could not obtain coordinate transform from GSE -> DSL'+ $
;             ', check for error from THM_COTRANS.'
;      dprint, dlevel=0, fail
;      return, -1
;    endif
;    sundir = ctd.y[0,*]
;    
;    ;Delete temporary tplot data
;    store_data, '*'+ctn+'*', /delete
;  endif else begin
;  
;    sundir = transpose([1,0,0]) ; By definition for GSE/GSM
;  
;  endelse
;
;  ;correct for rotation
;  sundir = slice.rot_m ## sundir
;  
;  ;correct for user specified rotations (*new slices only)
;  if n_elements(slice.orient_m) gt 1 then begin
;   sundir = slice.orient_m ## sundir
;  endif
;
;  return, sundir
;
;end


;+
;Purpose: 
;    Return an array of formatted annotation strings to be passed
;    to an IDL plotting procedure through the [xyz]tickname keyword.
;    
;    Associated tick values are returned via keyword (2013-April)
;         
;Notes:
;    - This function should be called after the plot window has been initialized;
;      otherwise, the AXIS procedure will create an extra window.   
;    - If the # of ticks is not specified it will be determined by IDL.
;         
;Input Keywords:
;   ticks:  # of ticks requested by user (optional)
;   range:  two element array specifying axis range
;   log:    flag to denote logarithmic axis (optional)
;
;Output:
;   tickname: String array of tick names
;   tickv: Array of tick values
;   ticks: Number of ticks - 1   
;   
;
;-
pro plot_part_slice2d_getticks, nticks=nticks, range=range, log=log, $
                                precision=precision, style=style, $
                                tickv=tickvals, tickname=ticknames, ticks=ticknum

    compile_opt idl2, hidden


  ;Adjust if # specified by user
  if size(nticks,/type) ne 0 then begin
    ticks = round(nticks) > 0 < 59
    ticks = ticks gt 1 ? ticks-1:(ticks > 1) ;n+1 plotted, =1 to supress
  endif
  
  ;Get the values of the default ticks generated by IDL 
  axis, yaxis=1, ystyle = 1+4, $
        yrange = range, ylog = log, $ 
        yticks = ticks, $
        ytick_get = tickvals

  ;Initialize output
  ticknames = strarr(n_elements(tickvals))
  ticknum = n_elements(tickvals)-1 

  ;Format ticks with custom routine
  for i=0, n_elements(tickvals)-1 do begin
    ticknames[i] = formatannotation(0,0,tickvals[i], $
      data={timeaxis:0,formatid:precision,scaling:0,exponent:style})
  endfor
  
  ;Use spaces to supress text for 0 or 1 ticks
  if size(nticks,/type) ne 0 then begin
    if nticks eq 1 then ticknames[1] = ' '
    if nticks lt 1 then ticknames[*] = ' '
  endif


end



;+
;Procedure: plot_part_slice2d
;
;Purpose: Create plots for 2D particle slices.
;
;Calling Sequence:
;  plot_part_slice2d, slice
;
;Arguments:
;  SLICE: 2D array of values to plot 
;
;Plotting Keywords:
;  RANGE: Two-element array specifying zaxis range (units vary)
;  [XY]RANGE: Two-element array specifying x/y axis range
; 
;  LEVELS: Number of color contour levels to plot (default is 60)
;  OLINES: Number of contour lines to plot (default is 0)
;  PLOTSIZE: The size of the plot in device units (usually pixels)
;            (Not yet implemented for postscript).
;  LOGPLOT: Boolean indicating plot should be log-scaled (on by default)
;  SUNDIR: Boolean to plot sun direction vector (on by default)
;  ECIRCLE: Boolean to plot circle(s) designating min/max energy 
;           from distribution (on by default)
;  PLOTAXES: Boolean to plot zero axes (on by default)
;  PLOTBULK: Boolean to plot projection of bulk velocity vector on the 
;            slice plane (on by default)
;            
;  CLABELS: Boolean to annotate contour lines.
;  CHARSIZE: Specifies character size of annotations (1 is normal)
;  [XYZ]TICKS: Integer(s) specifying the number of ticks for each axis 
;  [XYZ]PRECISION: Integer specifying annotation precision (sig. figs.).
;                  Set to zero to truncate printed values to inegers.
;  [XYZ]STYLE: Integer specifying annotation style:
;             Set to 0 (default) for style to be chosen automatically. 
;             Set to 1 for decimal annotations only ('0.0123') 
;             Set to 2 for scientific notation only ('1.23e-2')
;
;Exporting keywords:
; EXPORT: String designating the path and file name of the desired file. 
;         The plot will be exported to a PNG image by default.
; EPS: Boolean indicating that the plot should be exported to 
;      encapsulated postscript.
;
;
;Created by: A. Flores
;            Based on work by Bryan Kerr and Arjun Raj
;
;-

pro plot_part_slice2d, slice, $
                     ; Dummy vars to conserve backwards compatibility 
                     ; (should allow oldscripts to be run withouth issue)
                       xgrid, ygrid, slice_info, $
                     ; Range options
                       range=range, xrange=xrange, yrange=yrange, $
                     ; Basic plotting options
                       title=title, ztitle=ztitle, $ 
                       xtitle=xtitle, ytitle=ytitle, $
                       xticks=x_ticks, yticks=y_ticks, zticks=z_ticks, $
                       xminor=x_minor, yminor=y_minor, $
                       charsize=charsize, plotsize=plotsize, $
                       logplot=logplot, $
                     ; Annotations 
                       xstyle=xstyle, xprecision=xprecision, $
                       ystyle=ystyle, yprecision=yprecision, $
                       zstyle=zstyle, zprecision=zprecision, $
                     ; Contours
                       olines=olines, levels=levels, nlines=nlines, clabels=clabels, $
                     ; Other plotting options
                       plotaxes=plotaxes, ecircle=ecircle, sundir=sundir, $ 
                       plotbulk=plotbulk, $
                     ; Eport
                       export=export, eps=eps, $
                       _extra=_extra

    compile_opt idl2


  ; Return if variables are not set
  if size(slice,/type) ne 8 then begin
    fail = 'No data structure provided, canceling plot.'
    dprint, dlevel=0, fail
    return
  endif


  ; Defaults
  if slice.type eq 2 then begin
    if size(olines,/type) eq 0 then olines = 20
  endif
  if keyword_set(nlines) and ~keyword_set(levels) then levels = nlines ;temp
  if ~keyword_set(levels) then levels=60
  
  if size(logplot,/type) eq 0 then logplot=1b
  if size(plotaxes,/type) eq 0 then plotaxes=1b
;  if size(ecircle,/type) eq 0 then ecircle=1b ;todo: fix
  if size(plotbulk,/type) eq 0 then plotbulk=1b
;  if size(sundir,/type) eq 0 then sundir=1b ;may require STATE data

  if size(z_ticks,/type) eq 0 then z_ticks=11

  if size(xstyle,/type) eq 0 then xstyle=0
  if size(xprecision,/type) eq 0 then xprecision=4
  if size(ystyle,/type) eq 0 then ystyle=0
  if size(yprecision,/type) eq 0 then yprecision=4
  if size(zstyle,/type) eq 0 then zstyle=0
  if size(zprecision,/type) eq 0 then zprecision=4

  if ~keyword_set(plotsize) then plotsize = 500.
  plotsize = 100. > plotsize ;min size


  ;Open postscript file
  if keyword_set(export) && keyword_set(eps) then begin
    popen, export, encapsulated = 1, _extra=_extra
  endif


  ; Main Plot
  ; ---------

  ; X,Y,Z ranges
  if keyword_set(xrange) then begin
    xrange = minmax(xrange)
  endif else begin
    xrange = minmax(slice.xgrid)
  endelse

  if keyword_set(yrange) then begin
    yrange = minmax(yrange)
  endif else begin
    yrange = minmax(slice.ygrid)
  endelse

  if keyword_set(range) then begin
    range = minmax(range)    
  endif else begin
    ; The default range is the nonnegative, nonzero 
    ; min/max of the pre-interpolated data
    range = slice.range * [0.999,1.001] ;padding, # in thm_ui_slice2d should match this
  endelse
  if range[1] eq range[0] then begin
    dprint, dlevel=1,'Slice at '+time_string(slice.trange[0])+' has no data.'
    title = 'Error: No data in range!'
    range = [1,10.]
  endif 

  
  ; Set color contour levels
  if keyword_set(logplot) then begin
    colorlevels = 10.^(indgen(levels)/float(levels)*(alog10(range[1]) - alog10(range[0])) + alog10(range[0]))
  endif else begin
    colorlevels = (indgen(levels)/float(levels)*(range[1]-range[0])+range[0])
  endelse
  
  
  ; Set colors
  thecolors = round((indgen(levels)+1)*(!d.table_size-9)/levels)+7


  ; Get general annotations
  plot_part_slice2d_getinfo, slice, $
                             title=title, $
;                             subtitle=subtitle, $
                             xtitle=xtitle, $
                             ytitle=ytitle, $
                             ztitle=ztitle


  ; Format plot window
  ; The values here were largely determined by trial and error
  if !d.name ne 'PS' then begin

    plotxcsize = plotsize / !d.x_ch_size
    plotycsize = plotsize / !d.y_ch_size
    
    xmargin = [11,15 + (zprecision-3 > 0)]
    ymargin = [4,2]
    
    tsize = strlen(title) * 1.25
  
    xcsize = (total(xmargin) + plotxcsize) > tsize
    ycsize = (total(ymargin) + plotycsize) 

    device, window_state = wins
    
    ;ensure a free window is used if possible
    wn = !d.window le 1 or !d.window ge 32  ?  $
          min( where(wins eq 0) ) > 2 : !d.window
  
    window, wn, xsize = xcsize * !d.x_ch_size, $
            ysize = ycsize * !d.y_ch_size, $
            title = title

    xmargin[0] = xmargin[0] > 0.5*(xcsize - plotxcsize)
  endif

  
  ; Get tick annotations after window has been initialized, 
  ; this will avoid an extra window from being created by AXIS.
  ; Get x ticks & annotations
  plot_part_slice2d_getticks,nticks=x_ticks, range=xrange, style=xstyle, precision=xprecision, $
                             ticks=xticks, tickv=xtickv, tickname=xtickname
  
  ; x minor ticks, simulate default if not set
  ; use new name to avoid mutating input
  xminor = size(x_minor,/type) eq 0  ?  round(40./n_elements(xtickv)) : (round(x_minor)+1 > 0)

  
  ; Get y ticks & annotations
  plot_part_slice2d_getticks,nticks=y_ticks, range=yrange, style=ystyle, precision=yprecision, $
                             ticks=yticks, tickv=ytickv, tickname=ytickname
  
  ; y minor ticks, simulate default if not set
  ; use new name to avoid mutating input
  yminor = size(y_minor,/type) eq 0  ?  round(40./n_elements(ytickv)) : (round(y_minor)+1 > 0)


  ; Plot
  contour, slice.data, slice.xgrid, slice.ygrid, $
      levels = colorlevels, c_color = thecolors, charsize=charsize, $
      /isotropic, /closed, /follow, $
;      /cell_fill,  $     ; Cell fill does not appear necessary here
      /fill, $
      title = title, $
      xmargin = xmargin, $
      ymargin = ymargin, $
      xstyle = 1, $    ; Force range
      ystyle = 1, $    ;
      ticklen = 0.01,$
      xtickname = xtickname,$  ; 2012-June: Annotations now controled by 
      ytickname = ytickname,$  ;            formatannotation
      xminor = xminor,$   ; Allow minor ticks to persist
      yminor = yminor,$   ; when specifying # of major ticks
      xtickv = xtickv,$  ; 2013-April: Specify values to avoid inconsistencies
      ytickv = ytickv,$  ;             
      xticks = xticks, $  ; Number of ticks must be passed in with values 
      yticks = yticks, $  ; for them to be placed correctly
      xrange = xrange,$
      yrange = yrange,$
      xtitle = xtitle,$
      ytitle = ytitle


  ; Get z axis ticks
  plot_part_slice2d_getticks,nticks=z_ticks, range=range, log=logplot, $
                             style=zstyle, precision=zprecision, $
                             ticks=zticks, tickv=ztickv, tickname=ztickname
                             
  
  ; Draw z axis color bar
  ;  - both the number of ticks and the tick values must 
  ;    be passed in for them to be placed correctly
  draw_color_scale,range=range, log=logplot,title=ztitle, charsize=charsize, $
                   yticks=zticks, ytickv=ztickv, ytickname=ztickname



  ;Other Plotting Options
  ;----------------------

  ; Plot contour lines
  if keyword_set(olines) then begin

    ; set contour levels
    if keyword_set(logplot) then begin
      linelevels = 10.^(indgen(olines)/float(olines)*(alog10(range[1]) - alog10(range[0])) + alog10(range[0]))
    endif else begin
      linelevels = (indgen(olines)/float(olines)*(range[1]-range[0])+range[0])
    endelse

    contour, slice.data, slice.xgrid, slice.ygrid, $
        levels = linelevels, charsize=charsize,  $
        /overplot, /closed, /isotropic, $
        follow = clabels
  endif


  ; Plot axes
  if keyword_set(plotaxes) then begin
    oplot,[0.,0.],minmax(slice.ygrid),linestyle = 2,thick = 1
    oplot,minmax(slice.xgrid),[0.,0.],linestyle = 2,thick = 1
  endif
  

  ; Plot circle for minimum/maximum velocity 
  ; (based off energy limits) 
  if keyword_set(ecircle) then begin
    degrees = findgen(360)*!dtor
    
    ocircy=sin(degrees) * slice.vrange[1]
    ocircx=cos(degrees) * slice.vrange[1]
    icircy=sin(degrees) * slice.vrange[0]
    icircx=cos(degrees) * slice.vrange[0]
    
    
    ;adjust for subtraction of bulk velocity
    if keyword_set(slice.shift) then begin
      ocircy -= slice.shift[1]
      ocircx -= slice.shift[0]
      icircy -= slice.shift[1]
      icircx -= slice.shift[0]
    endif
    
    if slice.vrange[1] gt 0 then $
      oplot,ocircx,ocircy,thick = 1
    if slice.vrange[0] gt (yrange[1]-yrange[0])*0.015 then $
      oplot,icircx,icircy,thick = 1
  endif
  
  
  ; Plot the bulk velocity
  if keyword_set(plotbulk) and keyword_set(slice.bulk) $
    and ~keyword_set(shift) then begin
    ; bulk velocity should already be in the coords defined for
    ; the slice plane
    oplot, [0,slice.bulk[0]], [0,slice.bulk[1]], color=!d.table_size-9
  endif


  ; Plot sun direction
  if keyword_set(sundir) then begin
    if keyword_set(slice.sunvec) then begin
      sund_p = slice.sunvec[0:1] ;already in slice plane's coords
      oplot,[0,sund_p[0]*max(xrange)],[0,sund_p[1]*max(xrange)]
    endif else begin
      dprint, dlevel=1, 'To plot sun direction /GET_SUN_DIRECTION must'+ $ 
                        ' be used on call to thm_part_dist_array.' 
    endelse
  endif


  ; Finish export:  write .png or close postscript file 
  if keyword_set(export) then begin
    if keyword_set(eps) then begin
      pclose
    endif else begin
      makepng, export, /mkdir, _extra=_extra
    endelse
  endif


;  if keyword_set(o_part_slice) then begin
;    ; apply user specified scaling
;    if keyword_set(scale) then o_part_slice *= scale
;
;    contour, o_part_slice, o_xgrid, o_ygrid, $
;             levels = thelevels, c_color = thecolors, fill=1, $
;             /isotropic, /closed, /overplot
;
;    if keyword_set(olines) then begin
;      contour, o_part_slice, o_xgrid, o_ygrid, $
;          levels = thelevels2, charsize=charsize, follow = clabels, $
;          /isotropic, /closed, /overplot
;    endif
;
;  endif

end
