;+
;NAME:
;  thm_ui_load_goes_data_load_pro
;
;PURPOSE:
;  Modularized gui goes data loader
;
;
;HISTORY:
;$LastChangedBy: crussell $
;$LastChangedDate: 2013-01-09 08:29:50 -0800 (Wed, 09 Jan 2013) $
;$LastChangedRevision: 11403 $
;$URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/thmsoc/tags/tdas_8_00/idl/themis/thm_ui_new/panels/thm_ui_load_data_file/thm_ui_load_goes_data_load_pro.pro $
;
;--------------------------------------------------------------------------------

pro thm_ui_load_goes_data_load_pro,     $
                      loadStruc,        $
                      loadedData,       $
                      statusBar,        $
                      historyWin,       $
                      parent_widget_id, $
                      replay=replay,    $                      
                      overwrite_selections=overwrite_selections                            

  compile_opt hidden,idl2

  probe=loadStruc.probe
  dataType=loadStruc.datatype
  timeRange=loadStruc.timeRange
  
  loaded = 0
  
  goesmintime = '2007-01-01'
  goesmaxtime = '2008-12-31'

  new_vars = ''

  overwrite_selection='' 
  overwrite_count =0

  if ~keyword_set(replay) then begin
    overwrite_selections = ''
  endif

  tn_before = [tnames('*',create_time=cn_before)]
  
  thm_load_goesmag,$
               probe=probe,$
               datatype=datatype,$
               trange=timeRange
  
  thm_ui_cleanup_tplot,tn_before,create_time_before=cn_before,del_vars=to_delete,new_vars=new_vars
 
  if new_vars[0] ne '' then begin
    loaded = 1
    ;loop over loaded data
    for i = 0,n_elements(new_vars)-1 do begin
      
      if stregex(new_vars[i],'^g1[012]_dataqual.*',/boolean,/fold_case) || $
        stregex(new_vars[i],'^g1[012]_t[12]_counts.*',/boolean,/fold_case) then begin
        instrument = 'support'
      endif else if stregex(new_vars[i],'^g1[012]_longitude.*',/boolean,/fold_case) || $
                   stregex(new_vars[i],'^g1[012]_mlt.*',/boolean,/fold_case) || $
                   stregex(new_vars[i],'^g1[012]_pos.*',/boolean,/fold_case) || $
                   stregex(new_vars[i],'^g1[012]_vel.*',/boolean,/fold_case) then begin
        instrument = 'ephem'
      endif else begin
        instrument = 'fgm'
      endelse
      
      ;Check if data is already loaded, so that it can query user on whether they want to overwrite data
      if loadedData->isParent(new_vars[i]) then begin
        if overwrite_selection ne 'yestoall' AND overwrite_selection ne 'notoall' then begin
            if keyword_set(replay) then begin
              if overwrite_count ge n_elements(overwrite_selections) then begin
                historywin->update,"ERROR:Discrepancy in themis document, may have lead to a document load error"
                statusbar->update,"ERROR:Discrepancy in themis document, may have lead to a document load error"
                overwrite_selection = "yestoall"
              endif else begin
                overwrite_selection = overwrite_selections[overwrite_count]
              endelse
            endif else begin
              prompttext='The variable ' + strupcase(new_vars[i]) + ' already exists.  Do you want to ' + $
                    'overwrite it with the new variable?  If you click "No" the new ' + strupcase(new_vars[i]) + ' will not be loaded.'
  
;              ; loop so that hitting the widget kill button doesn't close the window            
              repeat overwrite_selection = thm_ui_prompt_widget(parent_widget_id, statusbar,historyWin,promptText= prompttext,defaultValue='',/yes,/no,/allyes,/allno,maxwidth=80,title="Overwrite Data?") until overwrite_selection ne ''

              overwrite_selections=array_concat(overwrite_selection,overwrite_selections)
            
            endelse
            overwrite_count++
          endif
            
          if overwrite_selection eq 'yes' OR overwrite_selection eq 'yestoall' then begin
            h = 'LOAD DATA: ' + strupcase(new_vars[i]) + ' will be overwritten.'
            historyWin->Update, h
            statusbar->Update, h
          endif
          if overwrite_selection eq 'no' OR overwrite_selection eq 'notoall' then begin
            h = 'LOAD DATA: ' + strupcase(new_vars[i]) + $
                ' not loaded into GUI to prevent overwrite of existing GUI data.'
            historyWin->Update, h
            statusbar->Update, h
             
            continue
          endif
      endif
      
      result = loadedData->add(new_vars[i],mission='GOES',instrument=instrument)
        
      if ~result then begin
        statusBar->update,'Error loading: ' + new_vars[i]
        historyWin->update,'GOES: Error loading: ' + new_vars[i]
        return
      endif
    endfor
  endif
    
  if to_delete[0] ne '' then begin
    store_data,to_delete,/delete
  endif
     
  if loaded eq 1 then begin
    statusBar->update,'GOES Data Loaded Successfully'
    historyWin->update,'GOES Data Loaded Successfully'
  endif else begin
  
    if time_double(goesmaxtime) lt time_double(timerange[0]) || $
       time_double(goesmintime) gt time_double(timerange[1]) then begin
       statusBar->update,'No GOES Data Loaded, GOES data is only available between ' + goesmintime + ' and ' + goesmaxtime
       historyWin->update,'No GOES Data Loaded,  GOES data is only available between ' + goesmintime + ' and ' + goesmaxtime
    endif else begin   
       statusBar->update,'No GOES Data Loaded'
       historyWin->update,'No GOES Data Loaded'
    endelse
    
  endelse

end