;+
;NAME:
;  thm_ui_load_wind_data_load_pro
;
;PURPOSE:
;  Modularized gui wind data loader
;
;
;HISTORY:
;$LastChangedBy: crussell $
;$LastChangedDate: 2013-01-09 08:29:50 -0800 (Wed, 09 Jan 2013) $
;$LastChangedRevision: 11403 $
;$URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/thmsoc/tags/tdas_8_00/idl/themis/thm_ui_new/panels/thm_ui_load_data_file/thm_ui_load_wind_data_load_pro.pro $
;
;--------------------------------------------------------------------------------
pro thm_ui_load_wind_data_load_pro,$
                         loadStruc,$
                         loadedData,$
                         statusBar,$
                         historyWin,$
                         parent_widget_id,$  ;needed for appropriate layering and modality of popups
                         replay=replay,$
                         overwrite_selections=overwrite_selections ;allows replay of user overwrite selections from themis 
                         

  compile_opt hidden,idl2

  instrument=loadStruc.instrument[0]
  datatype=loadStruc.datatype[0]
  parameters=loadStruc.parameters
  timeRange=loadStruc.timeRange
  loaded = 0

  new_vars = ''

  overwrite_selection=''
  overwrite_count =0

  if ~keyword_set(replay) then begin
    overwrite_selections = ''
  endif

  tn_before = [tnames('*',create_time=cn_before)]

  ;select the appropriate wind load routine
  if instrument eq 'or' then begin
    par_names = 'wi_'+datatype+'_or_'+parameters
    wi_or_load,datatype=datatype,trange=timeRange,varformat='*'
  endif else if instrument eq 'mfi' then begin
    par_names = 'wi_'+datatype+'_mfi_'+parameters
    wi_mfi_load,datatype=datatype,trange=timeRange,varformat='*'
  endif else if instrument eq 'swe' then begin
    par_names = 'wi_swe_' + parameters
    wi_swe_load,datatype=datatype,trange=timeRange,varformat='*'
  endif else if instrument eq '3dp' then begin
    ;CDF_LOAD_VARS crashes for some reason if varformat is '*' for datatype ='ELPD'
    if datatype eq 'elpd' then begin
      wi_3dp_load,datatype='elpd_old',trange=timeRange,varformat='TIME FLUX ENERGY PANGLE INTEG_T EDENS TEMP QP QM QT REDF VSW MAGF'
    endif else begin
      wi_3dp_load,datatype=datatype,trange=timeRange,varformat='*'
    endelse
    par_names = 'wi_3dp_'+datatype+'_'+parameters
  
  endif
  
  thm_ui_cleanup_tplot,tn_before,create_time_before=cn_before,del_vars=to_delete,new_vars=new_vars
  
  if new_vars[0] ne '' then begin
    ;only add the requested new parameters
    new_vars = ssl_set_intersection([par_names],[new_vars])
    loaded = 1
    ;loop over loaded data
    for i = 0,n_elements(new_vars)-1 do begin
    
      if stregex(new_vars[i],'gse',/fold_case,/boolean) then begin
        coordSys = 'gse'
      endif else if stregex(new_vars[i],'gsm',/fold_case,/boolean) then begin
        coordSys = 'gsm'
      endif else if stregex(new_vars[i],'GCI',/fold_case,/boolean) then begin
        coordSys = 'gci'
      endif else begin
        coordSys = ''
      endelse
     
      ;Check if data is already loaded, so that it can query user on whether they want to overwrite data
      if loadedData->isParent(new_vars[i]) then begin
        if overwrite_selection ne 'yestoall' AND overwrite_selection ne 'notoall' then begin
            if keyword_set(replay) then begin
              if overwrite_count ge n_elements(overwrite_selections) then begin
                historywin->update,"ERROR:Discrepancy in themis document, may have lead to a document load error"
                statusbar->update,"ERROR:Discrepancy in themis document, may have lead to a document load error"
                overwrite_selection = "yestoall"
              endif else begin
                overwrite_selection = overwrite_selections[overwrite_count]
              endelse
            endif else begin
              prompttext='The variable ' + strupcase(new_vars[i]) + ' already exists.  Do you want to ' + $
                    'overwrite it with the new variable?  If you click "No" the new ' + strupcase(new_vars[i]) + ' will not be loaded.'
  
;              ; loop so that hitting the widget kill button doesn't close the window            
              repeat overwrite_selection = thm_ui_prompt_widget(parent_widget_id, statusbar,historyWin,promptText= prompttext,defaultValue='',/yes,/no,/allyes,/allno,maxwidth=80,title="Overwrite Data?") until overwrite_selection ne ''

              overwrite_selections=array_concat(overwrite_selection,overwrite_selections)
            
            endelse
            
            overwrite_count++
          endif
            
          if overwrite_selection eq 'yes' OR overwrite_selection eq 'yestoall' then begin
            h = 'LOAD DATA: ' + strupcase(new_vars[i]) + ' will be overwritten.'
            historyWin->Update, h
            statusbar->Update, h
          endif
          if overwrite_selection eq 'no' OR overwrite_selection eq 'notoall' then begin
            h = 'LOAD DATA: ' + strupcase(new_vars[i]) + $
                ' not loaded into GUI to prevent overwrite of existing GUI data.'
            historyWin->Update, h
            statusbar->Update, h
             
            continue
          endif
      endif
      
      
      result = loadedData->add(new_vars[i],mission='WIND',observatory='WIND',instrument=instrument,coordSys=coordSys)
      
      if ~result then begin
        statusBar->update,'Error loading: ' + new_vars[i]
        historyWin->update,'WIND: Error loading: ' + new_vars[i]
        return
      endif
    endfor
  endif
    
  if n_elements(to_delete) gt 0 && is_string(to_delete) then begin
    store_data,to_delete,/delete
  endif
     
  if loaded eq 1 then begin
    statusBar->update,'WIND Data Loaded Successfully'
    historyWin->update,'WIND Data Loaded Successfully'
  endif else begin
    statusBar->update,'No WIND Data Loaded.  Data may not be available during this time interval.'
    historyWin->update,'No WIND Data Loaded.  Data may not be available during this time interval.'    
  endelse

end