;+ 
;NAME:
; thm_ui_run_calc
;
;PURPOSE:
; Function that interprets program for thm_ui_calculate
;
;CALLING SEQUENCE:
; thm_ui_run_calc,programtext,loadeddata,historywin,statusbar,error=error
;
;INPUT:
; programText: array of strings, text of program
; loadeddata: the loaded data object
; historywin: the historywin object
; statusbar: the statusbar object
;
;OUTPUT:
; error=error: set to named variable, will be 0 on success, will be set to error struct returned by calc.pro on failure
;
;HISTORY:
;$LastChangedBy: pcruce $
;$LastChangedDate: 2013-03-14 17:14:03 -0700 (Thu, 14 Mar 2013) $
;$LastChangedRevision: 11813 $
;$URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/thmsoc/tags/tdas_8_00/idl/themis/thm_ui_new/utilities/thm_ui_run_calc.pro $
;
;---------------------------------------------------------------------------------


pro thm_ui_run_calc,programtext,loadeddata,historywin,statusbar,error=error

  compile_opt hidden,idl2
  
  pi = !DPI
  e = exp(1)
  
  error = 0
  
  ;list of names so that we can delete any newly created names
  tn_before = tnames()
  
  for i = 0,n_elements(programtext)-1 do begin
  
    ;widget_control,state.programLabel,set_value="Calculating line: " + strtrim(string(i),2)
    
    statusBar->update,'Calculating line: ' + strtrim(string(i),2)
    historyWin->update,'Calculating line: ' + strtrim(string(i),2)
    
    if keyword_set(programtext[i]) then begin
      calc,programtext[i],gui_data_obj=loadedData,error=error
    endif
    
    if keyword_set(error) then begin
    
      break
    
    endif
  
  endfor
  
  ;list of names after processing
  thm_ui_cleanup_tplot,tn_before,del_vars=to_delete
  if to_delete[0] ne '' then begin
    store_data,to_delete,/delete
  endif
  
end
